@@ -17,13 +17,12 @@ class ConstructorTest extends OrmTestCase
 
 class ConstructorTestEntity1
 {
-    /** @var int */
-    private $id;
+    private int $id;
 
     /** @var string|null */
     public $username;
 
-    public function __construct(?string $username = null)
+    public function __construct(string|null $username = null)
     {
         if ($username !== null) {
             $this->username = $username;
