@@ -60,6 +60,7 @@ use function array_keys;
 use function assert;
 use function class_exists;
 use function count;
+use function defined;
 use function serialize;
 use function str_contains;
 use function str_replace;
@@ -199,6 +200,12 @@ class ClassMetadataTest extends OrmTestCase
         // float
         $cm->mapField(['fieldName' => 'float']);
         self::assertEquals('float', $cm->getTypeOfField('float'));
+
+        // number, requires DBAL 4.3+
+        if (defined(Types::class . '::NUMBER')) {
+            $cm->mapField(['fieldName' => 'bodyHeight']);
+            self::assertEquals('number', $cm->getTypeOfField('bodyHeight'));
+        }
     }
 
     #[TestGroup('GH10313')]
